@@ -14,7 +14,7 @@ def _cli():
         if (args.verbose):
             print(res.to_string())
 
-        sys.exit(res.verdict.return_code)
+        sys.exit(res.verdict.return_code);
 
 def check(input, user_output, judge_output, tokenizer = False, epsilon = None):
     with open(user_output) as user_out, open(judge_output) as judge_out:
@@ -25,4 +25,4 @@ def check(input, user_output, judge_output, tokenizer = False, epsilon = None):
         else:
             res = diff_checker.check(user_out, judge_out)
 
-    return res.to_string()
+    return res.to_JSON()
